@@ -138,7 +138,7 @@ class SearchableQuerySet(QuerySet):
         # terms that are explicitly required.
         elif optional:
             queryset = queryset.filter(reduce(ior, optional))
-        return queryset
+        return queryset.distinct()
 
     def _clone(self, *args, **kwargs):
         """
@@ -161,17 +161,30 @@ class SearchableQuerySet(QuerySet):
         If search has occurred and no ordering has occurred, decorate
         each result with the number of search terms so that it can be
         sorted by the number of occurrence of terms.
+
+        In the case of search fields that span model relationships, we
+        cannot accurately match occurrences without some very
+        complicated traversal code, which we won't attempt. So in this
+        case, namely when there are no matches for a result (count=0),
+        and search fields contain relationships (double underscores),
+        we assume one match for one of the fields, and use the average
+        weight of all search fields with relationships.
         """
         results = super(SearchableQuerySet, self).iterator()
         if self._search_terms and not self._search_ordered:
             results = list(results)
             for i, result in enumerate(results):
                 count = 0
+                related_weights = []
                 for (field, weight) in self._search_fields.items():
+                    if "__" in field:
+                        related_weights.append(weight)
                     for term in self._search_terms:
-                        field_value = getattr(result, field)
+                        field_value = getattr(result, field, None)
                         if field_value:
                             count += field_value.lower().count(term) * weight
+                if not count and related_weights:
+                    count = int(sum(related_weights) / len(related_weights))
                 results[i].result_count = count
             return iter(results)
         return results
@@ -306,6 +319,7 @@ class CurrentSiteManager(DjangoCSM):
     management commands with the ``--site`` arg, finally falling back
     to ``settings.SITE_ID`` if none of those match a site.
     """
+
     def __init__(self, field_name=None, *args, **kwargs):
         super(DjangoCSM, self).__init__(*args, **kwargs)
         self.__field_name = field_name
@@ -313,7 +327,11 @@ class CurrentSiteManager(DjangoCSM):
 
     def get_query_set(self):
         if not self.__is_validated:
-            self._validate_field_name()
+            try:
+                # Django <= 1.6
+                self._validate_field_name()
+            except AttributeError:
+                pass
         lookup = {self.__field_name + "__id__exact": current_site_id()}
         return super(DjangoCSM, self).get_query_set().filter(**lookup)
 
